.. _tag_install:

installation
============

.. |github_link| raw:: html

   <a href="https://github.com/biskilled/popEtl" target="_blank">GitHub</a>

You can dowload popEtl from |github_link| or by usin pip install::

    pip install popEtl


.. code-block:: python

    for i in range(10):
        print(i)


.. _tag_config:

configuration
=============

config is a class under config.py

